@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -178,7 +170,7 @@ void tst_qdeclarativemetatype::copy()
     QT_COPY_TEST(QRect, QRect(-10, 10, 102, 99));
     QT_COPY_TEST(QRectF, QRectF(-10.2, 1.2, 102, 99.6));
     QT_COPY_TEST(QSize, QSize(100, 2));
-    QT_COPY_TEST(QSizeF, QSizeF(20.2, -100234.2)); 
+    QT_COPY_TEST(QSizeF, QSizeF(20.2, -100234.2));
     QT_COPY_TEST(QLine, QLine(0, 0, 100, 100));
     QT_COPY_TEST(QLineF, QLineF(-10.2, 0, 103, 1));
     QT_COPY_TEST(QPoint, QPoint(-1912, 1613));
@@ -197,32 +189,32 @@ void tst_qdeclarativemetatype::copy()
 
     {
         QPixmap v = QPixmap(100, 100); QPixmap v2 = QPixmap(100, 100);
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QPixmap, &v, 0)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QPixmap, &v, 0));
         QVERIFY(v.size() == QPixmap().size());
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QPixmap , &v, &v2)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QPixmap , &v, &v2));
         QVERIFY(v.size() == QPixmap(100,100).size());
     }
 
     QT_COPY_TEST(QBrush, QBrush(Qt::blue));
     QT_COPY_TEST(QColor, QColor("lightsteelblue"));
     QT_COPY_TEST(QPalette, QPalette(Qt::green));
-    
+
     {
         QPixmap icon(100, 100);
 
         QIcon v = QIcon(icon); QIcon v2 = QIcon(icon);
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QIcon, &v, 0)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QIcon, &v, 0));
         QVERIFY(v.isNull() == QIcon().isNull());
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QIcon , &v, &v2)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QIcon , &v, &v2));
         QVERIFY(v.isNull() == QIcon(icon).isNull());
     }
 
     {
-        QImage v = QImage(100, 100, QImage::Format_RGB32); 
+        QImage v = QImage(100, 100, QImage::Format_RGB32);
         QImage v2 = QImage(100, 100, QImage::Format_RGB32);
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QImage, &v, 0)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QImage, &v, 0));
         QVERIFY(v.size() == QImage().size());
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QImage , &v, &v2)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QImage , &v, &v2));
         QVERIFY(v.size() == QImage(100,100, QImage::Format_RGB32).size());
     }
 
@@ -231,17 +223,17 @@ void tst_qdeclarativemetatype::copy()
 
     {
         QBitmap v = QBitmap(100, 100); QBitmap v2 = QBitmap(100, 100);
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QBitmap, &v, 0)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QBitmap, &v, 0));
         QVERIFY(v.size() == QBitmap().size());
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QBitmap , &v, &v2)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QBitmap , &v, &v2));
         QVERIFY(v.size() == QBitmap(100,100).size());
     }
 
     {
         QCursor v = QCursor(Qt::SizeFDiagCursor); QCursor v2 = QCursor(Qt::SizeFDiagCursor);
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QCursor, &v, 0)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QCursor, &v, 0));
         QVERIFY(v.shape() == QCursor().shape());
-        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QCursor , &v, &v2)); 
+        QVERIFY(QDeclarativeMetaType::copy(QMetaType::QCursor , &v, &v2));
         QVERIFY(v.shape() == QCursor(Qt::SizeFDiagCursor).shape());
     }
 
@@ -253,10 +245,10 @@ void tst_qdeclarativemetatype::copy()
     QT_COPY_TEST(QMatrix, QMatrix().translate(10, 10));
     QT_COPY_TEST(QTransform, QTransform().translate(10, 10));
     QT_COPY_TEST(QMatrix4x4, QMatrix4x4(1,0,2,3,0,1,0,0,9,0,1,0,0,0,10,1));
-    QT_COPY_TEST(QVector2D, QVector2D(10.2, 1));
-    QT_COPY_TEST(QVector3D, QVector3D(10.2, 1, -2));
-    QT_COPY_TEST(QVector4D, QVector4D(10.2, 1, -2, 1.2));
-    QT_COPY_TEST(QQuaternion, QQuaternion(1.0, 10.2, 1, -2));
+    QT_COPY_TEST(QVector2D, QVector2D(10.2f, 1));
+    QT_COPY_TEST(QVector3D, QVector3D(10.2f, 1, -2));
+    QT_COPY_TEST(QVector4D, QVector4D(10.2f, 1, -2, 1.2f));
+    QT_COPY_TEST(QQuaternion, QQuaternion(1.0, 10.2f, 1, -2));
 
     int voidValue;
     COPY_TEST(void *, VoidStar, (void *)&voidValue, (void *)0);
@@ -275,9 +267,9 @@ void tst_qdeclarativemetatype::copy()
     {
         QVariant tv = QVariant::fromValue(QVariant(10));
         QVariant v(tv); QVariant v2(tv);
-        QVERIFY(QDeclarativeMetaType::copy(qMetaTypeId<QVariant>(), &v, 0)); 
+        QVERIFY(QDeclarativeMetaType::copy(qMetaTypeId<QVariant>(), &v, 0));
         QVERIFY(v == QVariant());
-        QVERIFY(QDeclarativeMetaType::copy(qMetaTypeId<QVariant>(), &v, &v2)); 
+        QVERIFY(QDeclarativeMetaType::copy(qMetaTypeId<QVariant>(), &v, &v2));
         QVERIFY(v == tv);
     }
 
@@ -285,9 +277,9 @@ void tst_qdeclarativemetatype::copy()
         TestType t;  QVariant tv = QVariant::fromValue(&t);
 
         QVariant v(tv); QVariant v2(tv);
-        QVERIFY(QDeclarativeMetaType::copy(qMetaTypeId<TestType *>(), &v, 0)); 
+        QVERIFY(QDeclarativeMetaType::copy(qMetaTypeId<TestType *>(), &v, 0));
         QVERIFY(v == QVariant::fromValue((TestType *)0));
-        QVERIFY(QDeclarativeMetaType::copy(qMetaTypeId<TestType *>(), &v, &v2)); 
+        QVERIFY(QDeclarativeMetaType::copy(qMetaTypeId<TestType *>(), &v, &v2));
         QVERIFY(v == tv);
     }
 }
@@ -299,7 +291,7 @@ void tst_qdeclarativemetatype::qmlParserStatusCast()
     QCOMPARE(QDeclarativeMetaType::qmlType(qMetaTypeId<TestType *>())->parserStatusCast(), -1);
     QVERIFY(QDeclarativeMetaType::qmlType(qMetaTypeId<ValueSourceTestType *>()) != 0);
     QCOMPARE(QDeclarativeMetaType::qmlType(qMetaTypeId<ValueSourceTestType *>())->parserStatusCast(), -1);
-            
+
     QVERIFY(QDeclarativeMetaType::qmlType(qMetaTypeId<ParserStatusTestType *>()) != 0);
     int cast = QDeclarativeMetaType::qmlType(qMetaTypeId<ParserStatusTestType *>())->parserStatusCast();
     QVERIFY(cast != -1);
@@ -319,7 +311,7 @@ void tst_qdeclarativemetatype::qmlPropertyValueSourceCast()
     QCOMPARE(QDeclarativeMetaType::qmlType(qMetaTypeId<TestType *>())->propertyValueSourceCast(), -1);
     QVERIFY(QDeclarativeMetaType::qmlType(qMetaTypeId<ParserStatusTestType *>()) != 0);
     QCOMPARE(QDeclarativeMetaType::qmlType(qMetaTypeId<ParserStatusTestType *>())->propertyValueSourceCast(), -1);
-            
+
     QVERIFY(QDeclarativeMetaType::qmlType(qMetaTypeId<ValueSourceTestType *>()) != 0);
     int cast = QDeclarativeMetaType::qmlType(qMetaTypeId<ValueSourceTestType *>())->propertyValueSourceCast();
     QVERIFY(cast != -1);
@@ -339,7 +331,7 @@ void tst_qdeclarativemetatype::qmlPropertyValueInterceptorCast()
     QCOMPARE(QDeclarativeMetaType::qmlType(qMetaTypeId<TestType *>())->propertyValueInterceptorCast(), -1);
     QVERIFY(QDeclarativeMetaType::qmlType(qMetaTypeId<ParserStatusTestType *>()) != 0);
     QCOMPARE(QDeclarativeMetaType::qmlType(qMetaTypeId<ParserStatusTestType *>())->propertyValueInterceptorCast(), -1);
-            
+
     QVERIFY(QDeclarativeMetaType::qmlType(qMetaTypeId<ValueInterceptorTestType *>()) != 0);
     int cast = QDeclarativeMetaType::qmlType(qMetaTypeId<ValueInterceptorTestType *>())->propertyValueInterceptorCast();
     QVERIFY(cast != -1);
